@@ -71,6 +71,8 @@
 #' # Plot ensemble
 #' lines(boots["ensemble",]$ensemble, lwd = 3)
 #' 
+#' # Plot original
+#' lines(1:length(AirPassengers), AirPassengers, lwd = 3, col = "red")
 #' 
 #' ### Vectorized drift with a single rho
 #' boots <- NNS.meboot(AirPassengers, reps = 10, rho = 0, xmin = 0, target_drift = c(1,7))
@@ -100,221 +102,157 @@ NNS.meboot <- function(x,
                        xmin = NULL,
                        xmax = NULL,
                        reachbnd = TRUE,
-                       expand.sd = TRUE, force.clt = TRUE,
+                       expand.sd = TRUE,
+                       force.clt = TRUE,
                        scl.adjustment = FALSE, sym = FALSE, elaps = FALSE,
                        digits = 6,
-                       colsubj, coldata, coltimes,...)
-{
-  
-  if(length(x)==1) return(list(x=x))
+                       colsubj, coldata, coltimes, ...){
   
+  if (length(x) == 1) return(list(x = x))
   type <- tolower(type)
+  if (any(class(x) %in% c("tbl","data.table"))) x <- as.vector(unlist(x))
+  if (anyNA(x)) stop("You have some missing values, please address.")
   
-  if(any(class(x)%in%c("tbl","data.table"))) x <- as.vector(unlist(x))
-  
-  if(sum(is.na(x)) > 0) stop("You have some missing values, please address.")
-  
-  trim <- list(trim=trim, xmin=xmin, xmax=xmax)
-  
+  trim <- list(trim = trim, xmin = xmin, xmax = xmax)
   trimval <- if (is.null(trim$trim)) 0.1 else trim$trim
-  
   n <- length(x)
   
-  # Sort the original data in increasing order and
-  # store the ordering index vector.
+  # --- Fit original linear trend ONCE (time order) and get residuals
+  orig_lm        <- fast_lm(1:n, x)
+  orig_intercept <- orig_lm$coef[1]
+  orig_drift     <- orig_lm$coef[2]
+  orig_res       <- orig_lm$residuals
   
-  xx <- sort(x)
-  ordxx <- order(x)
-  
-  
-  if(!is.null(target_drift) || !is.null(target_drift_scale)) drift <- TRUE 
-
-  ordxx_2 <- rev(ordxx) 
-  
-  
-  # symmetry
-  
-  if (sym)
-  {
-    xxr <- rev(xx) #reordered values
-    xx.sym <- mean(xx) + 0.5*(xx - xxr) #symmetrized order stats
-    xx <- xx.sym #replace order stats by symmetrized ones
-  }
-  
-  # Compute intermediate points on the sorted series.
-  
-  z <- (xx[-1] + xx[-n])/2
-  
-  # Compute lower limit for left tail ('xmin') and
-  # upper limit for right tail ('xmax').
-  # This is done by computing the 'trim' (e.g. 10%) trimmed mean
-  # of deviations among all consecutive observations ('dv').
-  # Thus the tails are uniform distributed.
-  
-  dv <- abs(diff(as.numeric(x)))
-  dvtrim <- mean(dv, trim=trimval)
-  
-  if (is.list(trim))
-  {
-    if (is.null(trim$xmin))
-    {
-      xmin <- xx[1] - dvtrim
-    } else
-      xmin <- trim$xmin
-    
-    if (is.null(trim$xmax))
-    {
-      xmax <- xx[n] + dvtrim
-    } else
-      xmax <- trim$xmax
-    
-    if (!is.null(trim$xmin) || !is.null(trim$xmax))
-    {
-      if (isTRUE(force.clt))
-      {
-        expand.sd <- FALSE
-        force.clt <- FALSE
-        # warning("expand.sd and force.clt were set to FALSE in order to ",
-        #         "enforce the limits xmin/xmax.")
-      }
-    }
+  # Choose reconstruction slope (t = 1:n); for drift=FALSE baseline is flat at intercept (t = 0 fitted value)
+  if (!is.null(target_drift) || !is.null(target_drift_scale)) drift <- TRUE
+  if (drift) {
+    if (!is.null(target_drift_scale))      target_drift <- orig_drift * target_drift_scale
+    else if (is.null(target_drift))        target_drift <- orig_drift
+    recon_slope <- target_drift
   } else {
-    xmin <- xx[1] - dvtrim
-    xmax <- xx[n] + dvtrim
+    recon_slope <- 0
+  }
+  baseline <- orig_intercept + recon_slope * (1:n)
+  
+  # ===== MEBOOT CORE ON RESIDUALS ONLY =====
+  # Order stats, indices, symmetry, midpoints, tails computed from residuals
+  rr     <- orig_res
+  xx     <- sort(rr)
+  ordxx  <- order(rr)
+  ordxx_2 <- rev(ordxx)
+  
+  if (sym) {
+    xxr <- rev(xx)
+    xx  <- mean(xx) + 0.5 * (xx - xxr)
   }
   
+  z      <- (xx[-1] + xx[-n]) / 2
+  dv     <- abs(diff(as.numeric(rr)))
+  dvtrim <- mean(dv, trim = trimval)
   
-  # Compute the mean of the maximum entropy density within each
-  # interval in such a way that the 'mean preserving constraint'
-  # is satisfied. (Denoted as m_t in the reference paper.)
-  # The first and last interval means have distinct formulas.
-  # See Theil and Laitinen (1980) for details.
-  
-  aux <- colSums( t(cbind(xx[-c(1,2)], xx[-c(1,n)], xx[-c((n-1),n)]))*c(0.25,0.5,0.25) )
-  desintxb <- c(0.75*xx[1]+0.25*xx[2], aux, 0.25*xx[n-1]+0.75*xx[n])
-  
-  # Generate random numbers from the [0,1] uniform interval and
-  # compute sample quantiles at those points.
-  
-  # Generate random numbers from the [0,1] uniform interval.
-  
-  ensemble <- matrix(x, nrow=n, ncol=reps)
-  ensemble <- apply(ensemble, 2, NNS.meboot.part,
-                    n, z, xmin, xmax, desintxb, reachbnd)
-  
-  # So far the object 'ensemble' contains the quantiles.
-  # Now give them time series dependence and heterogeneity.
-  
-  qseq <- apply(ensemble, 2, sort)
-  
-  
-  # 'qseq' has monotonic series, the correct series is obtained
-  # after applying the order according to 'ordxx' defined above.
-  
-  ensemble[ordxx,] <- qseq
-  
-  
-  matrix2 = matrix(0, nrow=length(x), ncol = reps)
-  matrix2[ordxx_2,] <- qseq
-  
-  # Intial search
-  
-  e <- c(ensemble)
-  m <- c(matrix2)
-  l <- length(e)
-  
-  func <- function(ab, d = drift, ty = type) {
-    a <- ab[1]
-    b <- ab[2]
-    
-    # Compute the adjusted ensemble
-    combined <- (a * m + b * e) / (a + b)
-    
-    # Check correlation or dependence structure
-    if (ty == "spearman" || ty == "pearson") {
-      error <- abs(cor(combined, e, method = ty) - rho)
-    } else if (ty == "nnsdep") {
-      error <- abs(NNS.dep(combined, e)$Dependence - rho)
-    } else {
-      error <- abs(NNS.dep(combined, e)$Correlation - rho)
+  if (is.list(trim)) {
+    xmin <- if (is.null(trim$xmin)) xx[1] - dvtrim else trim$xmin
+    xmax <- if (is.null(trim$xmax)) xx[n] + dvtrim else trim$xmax
+    if (!is.null(trim$xmin) || !is.null(trim$xmax)) {
+      if (isTRUE(force.clt)) { expand.sd <- FALSE; force.clt <- FALSE }
     }
+  } else { xmin <- xx[1] - dvtrim; xmax <- xx[n] + dvtrim }
+  
+  # Theil–Laitinen interval means on residuals
+  aux <- colSums(t(cbind(xx[-c(1,2)], xx[-c(1,n)], xx[-c((n-1),n)])) * c(0.25, 0.5, 0.25))
+  desintxb <- c(0.75*xx[1] + 0.25*xx[2], aux, 0.25*xx[n-1] + 0.75*xx[n])
+  
+  # Quantile draws from max-entropy bootstrap IN RESIDUAL SPACE
+  res_mat <- matrix(rr, nrow = n, ncol = reps)
+  res_mat <- apply(res_mat, 2, NNS.meboot.part, n, z, xmin, xmax, desintxb, reachbnd)  
+  qseq <- apply(res_mat, 2, sort)
+  res_mat[ordxx, ] <- qseq
+  
+  # ===== Optional dependence targeting ρ in residual space (per replicate, time-aligned) =====
+  if (!is.null(rho)) {
+    rho_vec <- if (length(rho) == 1L) rep(rho, reps) else rep_len(rho, reps)
     
-    return(error)
+    # Ranks of original residuals for aligned vs anti-aligned extremes
+    r_o    <- rank(orig_res, ties.method = "average")
+    r_anti <- max(r_o) + 1 - r_o
+    
+    for (i in 1:reps) {
+      # start from each residual replicate column
+      res_i      <- res_mat[, i]
+      res_sorted <- sort(res_i)
+      e <- res_sorted[r_o]     # aligned with ranks of orig_res
+      m <- res_sorted[r_anti]  # anti-aligned
+      
+      rho_target <- rho_vec[i]
+      obj <- function(ab){
+        a <- ab[1]; b <- ab[2]
+        comb <- (a*m + b*e) / (a + b)
+        if (type %in% c("spearman","pearson")) {
+          abs(cor(comb, orig_res, method = type) - rho_target)
+        } else if (type == "nnsdep") {
+          abs(NNS.dep(comb, orig_res)$Dependence - rho_target)   
+        } else {
+          abs(NNS.dep(comb, orig_res)$Correlation - rho_target)
+        }
+      }
+      opt <- optim(c(0.5, 0.5), obj, control = list(abstol = 0.01))
+      res_mat[, i] <- (opt$par[1]*m + opt$par[2]*e) / sum(abs(opt$par))
+    }
   }
   
-  res <- optim(c(.5, .5), func, control=list(abstol = .01))
+  # ===== Variance expansion ON RESIDUALS (match sd to original residuals) =====
+  res_mat <- NNS.meboot.expand.sd(x = orig_res, ensemble = res_mat, ...) 
   
-  ensemble <- (res$par[1]*matrix2 + res$par[2]*ensemble) / (sum(abs(res$par)))
+  # ===== Reconstruct levels: baseline + residuals =====
+  ensemble <- sweep(res_mat, 1, baseline, "+")
   
-  
-  # Drift
-  orig_coef <- fast_lm(1:n, x)$coef
-  orig_intercept <- orig_coef[1]
-  orig_drift <- orig_coef[2]
-  
-  new_coef <- apply(ensemble, 2, function(i) fast_lm(1:n, i)$coef)
-  slopes <- new_coef[2,]
-  
-  if(drift){
-    if(!is.null(target_drift_scale)) target_drift <- orig_drift * target_drift_scale else if(is.null(target_drift)) target_drift <- orig_drift
-    new_slopes <- (target_drift - slopes)
-    ensemble <- ensemble + t(t(sapply(new_slopes, function(slope) cumsum(rep(slope, n)))))
-    
-    new_intercepts <- orig_intercept - new_coef[1,]
-    ensemble <- sweep(ensemble, 2, new_intercepts, FUN = "+")
-  } 
-  
-  
-  
-  if(identical(ordxx_2, ordxx)){
-    if(reps>1) ensemble <- t(apply(ensemble, 1, function(x) sample(x, size = reps, replace = TRUE)))
+  # Keep legacy “identical(ordxx_2, ordxx)” reshuffle 
+  if (identical(ordxx_2, ordxx)) {
+    if (reps > 1) ensemble <- t(apply(ensemble, 1, function(z) sample(z, size = reps, replace = TRUE)))
   }
   
+  # Optional level scaling toward sd(x) 
+  if (isTRUE(expand.sd)) {
+    ensemble <- NNS.meboot.expand.sd(x = x, ensemble = ensemble, ...)   
+  }
   
-  if(expand.sd) ensemble <- NNS.meboot.expand.sd(x=x, ensemble=ensemble, ...)
-  
-  if(force.clt && reps > 1) ensemble <- force.clt(x=x, ensemble=ensemble)
-  
-  
-  
-  # scale adjustment
+  # Optional CLT enforcement
+  if (force.clt && reps > 1) ensemble <- force.clt(x = x, ensemble = ensemble)
   
+  # Optional ME-density scale adjustment (same as before)
   if (scl.adjustment){
-    zz <- c(xmin,z,xmax) #extended list of z values
-    v <- diff(zz^2) / 12
+    zz <- c(xmin, z, xmax)
+    v  <- diff(zz^2) / 12
     xb <- mean(x)
     s1 <- sum((desintxb - xb)^2)
     uv <- (s1 + sum(v)) / n
-    desired.sd <- sd(x)
+    desired.sd  <- sd(x)
     actualME.sd <- sqrt(uv)
-    if (actualME.sd <= 0)
-      stop("actualME.sd<=0 Error")
-    out <- desired.sd / actualME.sd
-    kappa <- out - 1
-    
+    if (actualME.sd <= 0) stop("actualME.sd<=0 Error")
+    kappa <- (desired.sd / actualME.sd) - 1
     ensemble <- ensemble + kappa * (ensemble - xb)
   } else kappa <- NULL
   
-  # Force min / max values
-  if(!is.null(trim[[2]])) ensemble <- apply(ensemble, 2, function(z) pmax(trim[[2]], z))
-  if(!is.null(trim[[3]])) ensemble <- apply(ensemble, 2, function(z) pmin(trim[[3]], z))
+  # Enforce min / max if provided
+  if (!is.null(trim[[2]])) ensemble <- apply(ensemble, 2, function(z) pmax(trim[[2]], z))
+  if (!is.null(trim[[3]])) ensemble <- apply(ensemble, 2, function(z) pmin(trim[[3]], z))
   
-  
-  
-  
-  if(is.ts(x)){
-    ensemble <- ts(ensemble, frequency=frequency(x), start=start(x))
-    if(reps>1) dimnames(ensemble)[[2]] <- paste("Series", 1:reps)
+  # ts attributes
+  if (is.ts(x)) {
+    ensemble <- ts(ensemble, frequency = frequency(x), start = start(x))
+    if (reps > 1) dimnames(ensemble)[[2]] <- paste("Series", 1:reps)
   } else {
-    if(reps>1) dimnames(ensemble)[[2]] <- paste("Replicate", 1:reps)
+    if (reps > 1) dimnames(ensemble)[[2]] <- paste("Replicate", 1:reps)
   }
   
-  
-  
-  final <- list(x=x, replicates=round(ensemble, digits = digits), ensemble=Rfast::rowmeans(ensemble), xx=xx, z=z, dv=dv, dvtrim=dvtrim, xmin=xmin,
-                xmax=xmax, desintxb=desintxb, ordxx=ordxx, kappa = kappa)
-  
+  final <- list(x = x,
+                replicates = round(ensemble, digits = digits),
+                ensemble = Rfast::rowmeans(ensemble),
+                xx = xx, z = z, dv = dv, dvtrim = dvtrim,
+                xmin = xmin, xmax = xmax, desintxb = desintxb,
+                ordxx = ordxx, kappa = kappa)
   return(final)
 }
 
-NNS.meboot <- Vectorize(NNS.meboot, vectorize.args = c("rho", "target_drift", "target_drift_scale"))
\ No newline at end of file
+NNS.meboot <- Vectorize(NNS.meboot,
+                        vectorize.args = c("rho", "target_drift", "target_drift_scale"))
