@@ -34,7 +34,7 @@ NNS.norm <- function(X,
                      chart.type = NULL,
                      location = "topleft"){
   
-  if(sum(is.na(X)) > 0) stop("You have some missing values, please address.")
+  if(anyNA(X)) stop("You have some missing values, please address.")
   
   if(any(class(X)%in%c("tbl","data.table"))) X <- as.data.frame(X)
 
@@ -129,8 +129,6 @@ NNS.norm <- function(X,
     
   }
   
-  
-  
   return(X_Normalized)
   
 }
