@@ -5,9 +5,6 @@ Uni.caus <- function(x, y, tau, plot = TRUE){
 
   xy <- NNS.norm(cbind(x, y), linear = FALSE, chart.type = NULL)
 
-  NNS.x <- unlist(xy[ , 1])
-  NNS.y <- unlist(xy[ , 2])
-
   min.length <- min(length(x), length(y))
 
   x.vectors <- list(tau+1)
